{
    "$graph": [
        {
            "class": "Workflow",
            "label": "bgzip and index VCF",
            "inputs": [
                {
                    "type": "File",
                    "id": "#bgzip_and_index.cwl/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/vcf",
                            "id": "#bgzip_and_index.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#bgzip_and_index.cwl/bgzip"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/bgzip/bgzipped_file",
                            "id": "#bgzip_and_index.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/index/indexed_vcf"
                    ],
                    "id": "#bgzip_and_index.cwl/index"
                }
            ],
            "id": "#bgzip_and_index.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bgzip_and_index.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bgzip_and_index.cwl/indexed_vcf"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "cram_to_bam workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#cram_to_bam_and_index.cwl/cram"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#cram_to_bam_and_index.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#cram_to_bam_and_index.cwl/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#cram_to_bam_and_index.cwl/bam"
                }
            ],
            "steps": [
                {
                    "run": "#cram_to_bam.cwl",
                    "in": [
                        {
                            "source": "#cram_to_bam_and_index.cwl/cram",
                            "id": "#cram_to_bam_and_index.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#cram_to_bam_and_index.cwl/reference",
                            "id": "#cram_to_bam_and_index.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#cram_to_bam_and_index.cwl/cram_to_bam/bam"
                    ],
                    "id": "#cram_to_bam_and_index.cwl/cram_to_bam"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#cram_to_bam_and_index.cwl/cram_to_bam/bam",
                            "id": "#cram_to_bam_and_index.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#cram_to_bam_and_index.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#cram_to_bam_and_index.cwl/index_bam"
                }
            ],
            "id": "#cram_to_bam_and_index.cwl"
        },
        {
            "class": "Workflow",
            "label": "CLE gold vcf evaluation workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/gold_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#main/normal_cram"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "NORMAL",
                    "id": "#main/normal_sample_name"
                },
                {
                    "type": "string",
                    "id": "#main/output_dir"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/query_vcf"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "id": "#main/roi_bed"
                },
                {
                    "type": "File",
                    "id": "#main/true_negative_bed"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#main/tumor_cram"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "TUMOR",
                    "id": "#main/tumor_sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputSource": "#main/gather_to_sub_directory/gathered_directory",
                    "id": "#main/output_directory"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#main/gold_vcf_roi/intersect_result",
                            "id": "#main/bgzip_and_index_gold_roi/vcf"
                        }
                    ],
                    "out": [
                        "#main/bgzip_and_index_gold_roi/indexed_vcf"
                    ],
                    "id": "#main/bgzip_and_index_gold_roi"
                },
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#main/query_vcf_pass_roi/intersect_result",
                            "id": "#main/bgzip_and_index_query_pass_roi/vcf"
                        }
                    ],
                    "out": [
                        "#main/bgzip_and_index_query_pass_roi/indexed_vcf"
                    ],
                    "id": "#main/bgzip_and_index_query_pass_roi"
                },
                {
                    "run": "#combine_variants_concordance.cwl",
                    "in": [
                        {
                            "source": "#main/bgzip_and_index_gold_roi/indexed_vcf",
                            "id": "#main/combine_vcf/base_vcf"
                        },
                        {
                            "source": "#main/bgzip_and_index_query_pass_roi/indexed_vcf",
                            "id": "#main/combine_vcf/query_vcf"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/combine_vcf/reference"
                        }
                    ],
                    "out": [
                        "#main/combine_vcf/combined_vcf"
                    ],
                    "id": "#main/combine_vcf"
                },
                {
                    "run": "#eval_cle_gold.cwl",
                    "in": [
                        {
                            "source": "#main/combine_vcf/combined_vcf",
                            "id": "#main/evaluation/combined_vcf"
                        },
                        {
                            "source": "#main/normal_bam_readcount/indel_bam_readcount_tsv",
                            "id": "#main/evaluation/normal_indel_bam_readcount_tsv"
                        },
                        {
                            "source": "#main/normal_bam_readcount/snv_bam_readcount_tsv",
                            "id": "#main/evaluation/normal_snv_bam_readcount_tsv"
                        },
                        {
                            "source": "#main/sompy/sompy_out",
                            "id": "#main/evaluation/sompy_out"
                        },
                        {
                            "source": "#main/true_negative_intersect_query_indel/intersect_result",
                            "id": "#main/evaluation/tn_x_query_indel"
                        },
                        {
                            "source": "#main/true_negative_intersect_query_snv/intersect_result",
                            "id": "#main/evaluation/tn_x_query_snv"
                        },
                        {
                            "source": "#main/true_negative_roi/intersect_result",
                            "id": "#main/evaluation/true_negative_bed"
                        },
                        {
                            "source": "#main/tumor_bam_readcount/indel_bam_readcount_tsv",
                            "id": "#main/evaluation/tumor_indel_bam_readcount_tsv"
                        },
                        {
                            "source": "#main/tumor_bam_readcount/snv_bam_readcount_tsv",
                            "id": "#main/evaluation/tumor_snv_bam_readcount_tsv"
                        }
                    ],
                    "out": [
                        "#main/evaluation/eval_out",
                        "#main/evaluation/vaf_report"
                    ],
                    "id": "#main/evaluation"
                },
                {
                    "run": "#gather_to_sub_directory.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/evaluation/eval_out",
                                "#main/evaluation/vaf_report"
                            ],
                            "id": "#main/gather_to_sub_directory/files"
                        },
                        {
                            "source": "#main/output_dir",
                            "id": "#main/gather_to_sub_directory/outdir"
                        }
                    ],
                    "out": [
                        "#main/gather_to_sub_directory/gathered_directory"
                    ],
                    "id": "#main/gather_to_sub_directory"
                },
                {
                    "run": "#bedtools_intersect.cwl",
                    "in": [
                        {
                            "source": "#main/gold_vcf",
                            "id": "#main/gold_vcf_roi/file_a"
                        },
                        {
                            "source": "#main/roi_bed",
                            "id": "#main/gold_vcf_roi/file_b"
                        },
                        {
                            "default": false,
                            "id": "#main/gold_vcf_roi/output_file_a"
                        },
                        {
                            "default": "gold_roi.vcf",
                            "id": "#main/gold_vcf_roi/output_name"
                        },
                        {
                            "default": false,
                            "id": "#main/gold_vcf_roi/unique_result"
                        }
                    ],
                    "out": [
                        "#main/gold_vcf_roi/intersect_result"
                    ],
                    "id": "#main/gold_vcf_roi"
                },
                {
                    "run": "#bam_readcount.cwl",
                    "in": [
                        {
                            "source": "#main/normal_cram_to_bam_and_index/bam",
                            "id": "#main/normal_bam_readcount/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/normal_bam_readcount/reference_fasta"
                        },
                        {
                            "source": "#main/normal_sample_name",
                            "id": "#main/normal_bam_readcount/sample"
                        },
                        {
                            "source": "#main/combine_vcf/combined_vcf",
                            "id": "#main/normal_bam_readcount/vcf"
                        }
                    ],
                    "out": [
                        "#main/normal_bam_readcount/snv_bam_readcount_tsv",
                        "#main/normal_bam_readcount/indel_bam_readcount_tsv"
                    ],
                    "id": "#main/normal_bam_readcount"
                },
                {
                    "run": "#cram_to_bam_and_index.cwl",
                    "in": [
                        {
                            "source": "#main/normal_cram",
                            "id": "#main/normal_cram_to_bam_and_index/cram"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/normal_cram_to_bam_and_index/reference"
                        }
                    ],
                    "out": [
                        "#main/normal_cram_to_bam_and_index/bam"
                    ],
                    "id": "#main/normal_cram_to_bam_and_index"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/query_vcf_pass/exclude_filtered"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/query_vcf_pass/reference"
                        },
                        {
                            "source": "#main/query_vcf",
                            "id": "#main/query_vcf_pass/vcf"
                        }
                    ],
                    "out": [
                        "#main/query_vcf_pass/filtered_vcf"
                    ],
                    "id": "#main/query_vcf_pass"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "source": "#main/reference",
                            "id": "#main/query_vcf_pass_indel/reference"
                        },
                        {
                            "default": "INDEL",
                            "id": "#main/query_vcf_pass_indel/select_type"
                        },
                        {
                            "source": "#main/bgzip_and_index_query_pass_roi/indexed_vcf",
                            "id": "#main/query_vcf_pass_indel/vcf"
                        }
                    ],
                    "out": [
                        "#main/query_vcf_pass_indel/filtered_vcf"
                    ],
                    "id": "#main/query_vcf_pass_indel"
                },
                {
                    "run": "#bedtools_intersect.cwl",
                    "in": [
                        {
                            "source": "#main/query_vcf_pass/filtered_vcf",
                            "id": "#main/query_vcf_pass_roi/file_a"
                        },
                        {
                            "source": "#main/roi_bed",
                            "id": "#main/query_vcf_pass_roi/file_b"
                        },
                        {
                            "default": false,
                            "id": "#main/query_vcf_pass_roi/output_file_a"
                        },
                        {
                            "default": "query_pass_roi.vcf",
                            "id": "#main/query_vcf_pass_roi/output_name"
                        },
                        {
                            "default": false,
                            "id": "#main/query_vcf_pass_roi/unique_result"
                        }
                    ],
                    "out": [
                        "#main/query_vcf_pass_roi/intersect_result"
                    ],
                    "id": "#main/query_vcf_pass_roi"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "source": "#main/reference",
                            "id": "#main/query_vcf_pass_snv/reference"
                        },
                        {
                            "default": "SNP",
                            "id": "#main/query_vcf_pass_snv/select_type"
                        },
                        {
                            "source": "#main/bgzip_and_index_query_pass_roi/indexed_vcf",
                            "id": "#main/query_vcf_pass_snv/vcf"
                        }
                    ],
                    "out": [
                        "#main/query_vcf_pass_snv/filtered_vcf"
                    ],
                    "id": "#main/query_vcf_pass_snv"
                },
                {
                    "run": "#sompy.cwl",
                    "in": [
                        {
                            "source": "#main/query_vcf_pass/filtered_vcf",
                            "id": "#main/sompy/query_vcf"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/sompy/reference"
                        },
                        {
                            "source": "#main/roi_bed",
                            "id": "#main/sompy/roi_bed"
                        },
                        {
                            "source": "#main/gold_vcf",
                            "id": "#main/sompy/truth_vcf"
                        }
                    ],
                    "out": [
                        "#main/sompy/sompy_out"
                    ],
                    "id": "#main/sompy"
                },
                {
                    "run": "#bedtools_intersect.cwl",
                    "in": [
                        {
                            "source": "#main/true_negative_roi/intersect_result",
                            "id": "#main/true_negative_intersect_query_indel/file_a"
                        },
                        {
                            "source": "#main/query_vcf_pass_indel/filtered_vcf",
                            "id": "#main/true_negative_intersect_query_indel/file_b"
                        },
                        {
                            "default": false,
                            "id": "#main/true_negative_intersect_query_indel/output_file_a"
                        },
                        {
                            "default": "tn_x_query_indel.bed",
                            "id": "#main/true_negative_intersect_query_indel/output_name"
                        },
                        {
                            "default": false,
                            "id": "#main/true_negative_intersect_query_indel/unique_result"
                        }
                    ],
                    "out": [
                        "#main/true_negative_intersect_query_indel/intersect_result"
                    ],
                    "id": "#main/true_negative_intersect_query_indel"
                },
                {
                    "run": "#bedtools_intersect.cwl",
                    "in": [
                        {
                            "source": "#main/true_negative_roi/intersect_result",
                            "id": "#main/true_negative_intersect_query_snv/file_a"
                        },
                        {
                            "source": "#main/query_vcf_pass_snv/filtered_vcf",
                            "id": "#main/true_negative_intersect_query_snv/file_b"
                        },
                        {
                            "default": false,
                            "id": "#main/true_negative_intersect_query_snv/output_file_a"
                        },
                        {
                            "default": "tn_x_query_snv.bed",
                            "id": "#main/true_negative_intersect_query_snv/output_name"
                        },
                        {
                            "default": false,
                            "id": "#main/true_negative_intersect_query_snv/unique_result"
                        }
                    ],
                    "out": [
                        "#main/true_negative_intersect_query_snv/intersect_result"
                    ],
                    "id": "#main/true_negative_intersect_query_snv"
                },
                {
                    "run": "#bedtools_intersect.cwl",
                    "in": [
                        {
                            "source": "#main/true_negative_bed",
                            "id": "#main/true_negative_roi/file_a"
                        },
                        {
                            "source": "#main/roi_bed",
                            "id": "#main/true_negative_roi/file_b"
                        },
                        {
                            "default": false,
                            "id": "#main/true_negative_roi/output_file_a"
                        },
                        {
                            "default": "tn_roi.bed",
                            "id": "#main/true_negative_roi/output_name"
                        },
                        {
                            "default": false,
                            "id": "#main/true_negative_roi/unique_result"
                        }
                    ],
                    "out": [
                        "#main/true_negative_roi/intersect_result"
                    ],
                    "id": "#main/true_negative_roi"
                },
                {
                    "run": "#bam_readcount.cwl",
                    "in": [
                        {
                            "source": "#main/tumor_cram_to_bam_and_index/bam",
                            "id": "#main/tumor_bam_readcount/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/tumor_bam_readcount/reference_fasta"
                        },
                        {
                            "source": "#main/tumor_sample_name",
                            "id": "#main/tumor_bam_readcount/sample"
                        },
                        {
                            "source": "#main/combine_vcf/combined_vcf",
                            "id": "#main/tumor_bam_readcount/vcf"
                        }
                    ],
                    "out": [
                        "#main/tumor_bam_readcount/snv_bam_readcount_tsv",
                        "#main/tumor_bam_readcount/indel_bam_readcount_tsv"
                    ],
                    "id": "#main/tumor_bam_readcount"
                },
                {
                    "run": "#cram_to_bam_and_index.cwl",
                    "in": [
                        {
                            "source": "#main/tumor_cram",
                            "id": "#main/tumor_cram_to_bam_and_index/cram"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/tumor_cram_to_bam_and_index/reference"
                        }
                    ],
                    "out": [
                        "#main/tumor_cram_to_bam_and_index/bam"
                    ],
                    "id": "#main/tumor_cram_to_bam_and_index"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "run bam-readcount",
            "baseCommand": [
                "/usr/bin/python",
                "bam_readcount_helper.py"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bam_readcount_helper-cwl:1.1.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "bam_readcount_helper.py",
                            "entry": "#!/usr/bin/env python\n\nimport sys\nimport os\nfrom cyvcf2 import VCF\nimport tempfile\nimport csv\nfrom subprocess import Popen, PIPE\n\ndef generate_region_list(hash):\n    fh = tempfile.NamedTemporaryFile('w', delete=False)\n    writer = csv.writer(fh, delimiter='\\t')\n    for chr, positions in hash.items():\n        for pos in sorted(positions.keys()):\n            writer.writerow([chr, pos, pos])\n    fh.close()\n    return fh.name\n\ndef filter_sites_in_hash(region_list, bam_file, ref_fasta, prefixed_sample, output_dir, insertion_centric, map_qual, base_qual):\n    bam_readcount_cmd = ['/usr/bin/bam-readcount', '-f', ref_fasta, '-l', region_list, '-w', '0', '-b', str(base_qual), '-q', str(map_qual)]\n    if insertion_centric:\n        bam_readcount_cmd.append('-i')\n        output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_indel.tsv')\n    else:\n        output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_snv.tsv')\n    bam_readcount_cmd.append(bam_file)\n    execution = Popen(bam_readcount_cmd, stdout=PIPE, stderr=PIPE)\n    stdout, stderr = execution.communicate()\n    if execution.returncode == 0:\n        with open(output_file, 'wb') as output_fh:\n            output_fh.write(stdout)\n    else:\n        sys.exit(stderr)\n\n#initializing these with default values\nmin_base_qual = 20\nmin_mapping_qual = 0\n\nif len(sys.argv) == 7:\n    (script_name, vcf_filename, sample, ref_fasta, bam_file, prefix, output_dir)= sys.argv\nelif len(sys.argv) == 8:\n    (script_name, vcf_filename, sample, ref_fasta, bam_file, prefix, output_dir, min_base_qual)= sys.argv\nelif len(sys.argv) == 9: #elif instead of else for explicit safety\n    (script_name, vcf_filename, sample, ref_fasta, bam_file, prefix, output_dir, min_base_qual, min_mapping_qual)= sys.argv\n\nif prefix == 'NOPREFIX':\n    prefixed_sample = sample\nelse:\n    prefixed_sample = '_'.join([prefix, sample])\n\nvcf_file = VCF(vcf_filename)\nsample_index = vcf_file.samples.index(sample)\n\nrc_for_indel = {}\nrc_for_snp   = {}\nfor variant in vcf_file:\n    ref = variant.REF\n    chr = variant.CHROM\n    start = variant.start\n    end = variant.end\n    pos = variant.POS\n    for var in  variant.ALT:\n        if len(ref) > 1 or len(var) > 1:\n            #it's an indel or mnp\n            if len(ref) == len(var) or (len(ref) > 1 and len(var) > 1):\n                sys.stderr.write(\"Complex variant or MNP will be skipped: %s\\t%s\\t%s\\t%s\\n\" % (chr, pos, ref , var))\n                continue\n            elif len(ref) > len(var):\n                #it's a deletion\n                pos += 1\n                unmodified_ref = ref\n                ref = unmodified_ref[1]\n                var = \"-%s\" % unmodified_ref[1:]\n            else:\n                #it's an insertion\n                var = \"+%s\" % var[1:]\n            if chr not in rc_for_indel:\n                rc_for_indel[chr] = {}\n            if pos not in rc_for_indel[chr]:\n                rc_for_indel[chr][pos] = {}\n            if ref not in rc_for_indel[chr][pos]:\n                rc_for_indel[chr][pos][ref] = {}\n            rc_for_indel[chr][pos][ref] = variant\n        else:\n            #it's a SNP\n            if chr not in rc_for_snp:\n                rc_for_snp[chr] = {}\n            if pos not in rc_for_snp[chr]:\n                rc_for_snp[chr][pos] = {}\n            if ref not in rc_for_snp[chr][pos]:\n                rc_for_snp[chr][pos][ref] = {}\n            rc_for_snp[chr][pos][ref] = variant\n\nif len(rc_for_snp.keys()) > 0:\n    region_file = generate_region_list(rc_for_snp)\n    filter_sites_in_hash(region_file, bam_file, ref_fasta, prefixed_sample, output_dir, False, min_mapping_qual, min_base_qual)\nelse:\n    output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_snv.tsv')\n    open(output_file, 'w').close()\n\nif len(rc_for_indel.keys()) > 0:\n    region_file = generate_region_list(rc_for_indel)\n    filter_sites_in_hash(region_file, bam_file, ref_fasta, prefixed_sample, output_dir, True, min_mapping_qual, min_base_qual)\nelse:\n    output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_indel.tsv')\n    open(output_file, 'w').close()\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": -3
                }
            ],
            "stdout": "$(inputs.sample)_bam_readcount.tsv",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -5
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bam_readcount.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20,
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#bam_readcount.cwl/min_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#bam_readcount.cwl/min_mapping_quality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "NOPREFIX",
                    "inputBinding": {
                        "position": -4
                    },
                    "id": "#bam_readcount.cwl/prefix"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": -6
                    },
                    "id": "#bam_readcount.cwl/reference_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -7
                    },
                    "id": "#bam_readcount.cwl/sample"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -8
                    },
                    "id": "#bam_readcount.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    var name = \"_bam_readcount_indel.tsv\";\n    if (inputs.prefix.equals(\"NOPREFIX\")) {\n        name = inputs.sample + name;\n    }\n    else {\n        name = inputs.prefix + \"_\" + inputs.sample + name;\n    }\n    return name;\n}\n"
                    },
                    "id": "#bam_readcount.cwl/indel_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    var name = \"_bam_readcount_snv.tsv\";\n    if (inputs.prefix.equals(\"NOPREFIX\")) {\n        name = inputs.sample + name;\n    }\n    else {\n        name = inputs.prefix + \"_\" + inputs.sample + name;\n    }\n    return name;\n}\n"
                    },
                    "id": "#bam_readcount.cwl/snv_bam_readcount_tsv"
                }
            ],
            "id": "#bam_readcount.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/opt/ccdg/bedtools-2.27.1/bin/bedtools",
                "intersect"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ernfrid/bedtools:v2.27.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.output_name)",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-a"
                    },
                    "doc": "BAM/BED/GFF/VCF file to compare to file b",
                    "id": "#bedtools_intersect.cwl/file_a"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-b"
                    },
                    "doc": "BAM/BED/GFF/VCF file to compare to file a",
                    "id": "#bedtools_intersect.cwl/file_b"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-wa"
                    },
                    "doc": "Write the original entry in A for each overlap, default to true",
                    "id": "#bedtools_intersect.cwl/output_file_a"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-header"
                    },
                    "doc": "Print the header from the A file prior to results, default to true",
                    "id": "#bedtools_intersect.cwl/output_header"
                },
                {
                    "type": "string",
                    "id": "#bedtools_intersect.cwl/output_name"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-u"
                    },
                    "doc": "Write original A entry once if any overlaps found in B, default to true",
                    "id": "#bedtools_intersect.cwl/unique_result"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bedtools_intersect.cwl/intersect_result",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    }
                }
            ],
            "id": "#bedtools_intersect.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/usr/local/bin/bgzip"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.11--h6270b1f_0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "CombineVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "CombineVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 9000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-genotypeMergeOptions",
                "PRIORITIZE",
                "--rod_priority_list",
                "query,base",
                "-setKey",
                "source",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/combined_concordance.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:base",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants_concordance.cwl/base_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:query",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants_concordance.cwl/query_vcf"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#combine_variants_concordance.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "combined_concordance.vcf.gz"
                    },
                    "id": "#combine_variants_concordance.cwl/combined_vcf"
                }
            ],
            "id": "#combine_variants_concordance.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools view cram to bam",
            "baseCommand": [
                "/usr/local/bin/samtools",
                "view",
                "-b"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.11--h6270b1f_0"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.cram.nameroot).bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#cram_to_bam.cwl/cram"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#cram_to_bam.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.cram.nameroot).bam"
                    },
                    "id": "#cram_to_bam.cwl/bam"
                }
            ],
            "id": "#cram_to_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Make CLE gold evaluation output and vaf report",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:bionic"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "eval_cle_gold.pl",
                            "entry": "#!/usr/bin/perl\n\nuse strict;\nuse warnings;\n\nuse feature qw(say);\n\ndie(\"wrong number of arguments, 10 are needed\") unless scalar(@ARGV) == 10;\nmy ($out_dir, $sompy_out, $tn_bed, $tn_query_snv_bed, $tn_query_indel_bed, $vcf, $n_snv_br, $n_indel_br, $t_snv_br, $t_indel_br) = @ARGV;\n\nmy $tn_size = bed_size($tn_bed);\nmy $tn_query_snv_size = bed_size($tn_query_snv_bed);\nmy $tn_query_indel_size = bed_size($tn_query_indel_bed);\n\nmy $snv_specificity   = sprintf(\"%.9f\", ($tn_size-$tn_query_snv_size)/$tn_size);\nmy $indel_specificity = sprintf(\"%.9f\", ($tn_size-$tn_query_indel_size)/$tn_size);\nopen(my $sompy_fh, $sompy_out) or die(\"couldn't open $sompy_out to read\");\nopen(my $eval_out_fh, \">$out_dir/gold_eval.out\") or die(\"couldn't open gold_eval.out for write\");\n\nwhile (<$sompy_fh>) {\n   next if /^\\s+$|\\s+records\\s+/;\n   chomp;\n   if (/^\\s+type\\s+/) {\n       say $eval_out_fh $_.\"  specificity\";\n   }\n   elsif (/\\s+indels\\s+/) {\n       say $eval_out_fh $_.\"  \".$indel_specificity;\n   }\n   elsif (/\\s+SNVs\\s+/) {\n       say $eval_out_fh $_.\"  \".$snv_specificity;\n   }\n}\nclose $sompy_fh;\nclose $eval_out_fh;\n\nmy $t_snv_bamrc_info   = get_bamrc_info($t_snv_br);\nmy $t_indel_bamrc_info = get_bamrc_info($t_indel_br);\nmy $n_snv_bamrc_info   = get_bamrc_info($n_snv_br);\nmy $n_indel_bamrc_info = get_bamrc_info($n_indel_br);\n\nmy $vaf_out = $out_dir. '/vaf_report.out';\nopen(my $out_fh, \">$vaf_out\") or die \"fail to write to $vaf_out\";\n\nsay $out_fh join \"\\t\", 'Chr', 'Pos', 'Ref', 'Alt', 'Gold', 'Query', 'Normal_Dp', 'Normal_Vaf', 'Tumor_Dp', 'Tumor_Vaf';\n\nopen(my $fh, \"/bin/gunzip -c $vcf |\") or die(\"couldn't open $vcf to read\");\n\nwhile (<$fh>) {\n    next if $_ =~ /^#/;\n    my @columns = split /\\t/, $_;\n    my ($chr, $pos, $ref, $alt, $info) = map{$columns[$_]}qw(0 1 3 4 7);\n\n    my ($base, $query);\n    if ($info =~ /source=Intersection/) {\n        ($base, $query) = (1, 1);\n    }\n    elsif ($info =~ /source=base/) {\n        ($base, $query) = (1, 0);\n    }\n    elsif ($info =~ /source=query/) {\n        ($base, $query) = (0, 1);\n    }\n    elsif ($info =~ /source=(FilteredInAll|filterInquery-base|query-filterInbase)/) {\n        ($base, $query) = ('-', '-');\n    }\n    else {\n        die \"Line $_ does not have source info\";\n    }\n\n    my @alts = split /,/, $alt;\n    my ($n_AF, $n_dp) = get_AF_dp($chr, $pos, $ref, $alts[0], $n_snv_bamrc_info, $n_indel_bamrc_info);\n    my ($t_AF, $t_dp) = get_AF_dp($chr, $pos, $ref, $alts[0], $t_snv_bamrc_info, $t_indel_bamrc_info);\n    say $out_fh join \"\\t\", $chr, $pos, $ref, $alt, $base, $query, $n_dp, $n_AF, $t_dp, $t_AF;\n}\n$fh->close;\n\nsub bed_size {\n    my $bed = shift;\n    my $size = 0;\n    open(my $fh, $bed) or die \"could not open $bed for read\";\n    while (<$fh>) {\n        my (undef, $start, $end) = split /\\t/, $_;\n        $size += $end - $start;\n    }\n    close $fh;\n    return $size;\n}\n\nsub get_bamrc_info {\n    my $bamrc = shift;\n    my $bamrc_info;\n\n    open(my $bamrc_fh, $bamrc) or die \"failed to open $bamrc for read\";\n    while (<$bamrc_fh>) {\n        chomp;\n        my ($chr, $pos, $ref, $depth, $rest) = $_ =~ /^(.+)\\t(\\d+)\\t([AaCcGgTtRrYyKkMmSsWwBbDdHhVvNn])\\t(\\d+)\\t(.+)$/x; \n        my @allele_info = split /\\t/, $rest;\n        my $allele_ct;\n        for my $allele_str (@allele_info) {\n            my @info = split /:/, $allele_str;\n            $allele_ct->{$info[0]} = $info[1];\n        }\n        $bamrc_info->{$chr.'__'.$pos} = {\n            ref => $ref,\n            depth => $depth,\n            allele_ct => $allele_ct,\n        };\n    }\n    close $bamrc_fh;\n    return $bamrc_info;\n}\n\nsub get_AF_dp {\n    my ($chr, $pos, $ref, $alt, $snv_br_info, $indel_br_info) = @_;\n    my ($AF, $dp) = ('NA', 'NA');\n    \n    if (length($ref) == 1 and length($alt) == 1) { #SNV\n        my $id = $chr .'__'.$pos;\n        my $br_info = $snv_br_info->{$id};\n        if ($br_info) {\n            $AF = sprintf(\"%.5f\", $br_info->{allele_ct}->{$alt}/$br_info->{depth});\n            $dp = $br_info->{depth};\n        }\n    }\n    else {\n        my ($indel_pos, $bamrc_str);\n        if (length($ref) > length($alt)) { #DEL\n            $indel_pos = $pos + 1;\n            $bamrc_str = '-'.substr($ref, length($alt));\n        }\n        else { #INS\n            $indel_pos = $pos;\n            $bamrc_str = '+'.substr($alt, length($ref));\n        }\n        my $id = $chr.'__'.$indel_pos;\n        my $br_info = $indel_br_info->{$id};\n        if ($br_info) {\n            my $alt_ct = exists $br_info->{allele_ct}->{$bamrc_str} ? $br_info->{allele_ct}->{$bamrc_str} : 0;\n            $AF = sprintf(\"%.5f\", $alt_ct/$br_info->{depth});\n            $dp = $br_info->{depth};\n        }\n    }\n    return ($AF, $dp);\n}\n"
                        }
                    ]
                }
            ],
            "arguments": [
                "/usr/bin/perl",
                "eval_cle_gold.pl",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#eval_cle_gold.cwl/combined_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#eval_cle_gold.cwl/normal_indel_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 6
                    },
                    "id": "#eval_cle_gold.cwl/normal_snv_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#eval_cle_gold.cwl/sompy_out"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#eval_cle_gold.cwl/tn_x_query_indel"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#eval_cle_gold.cwl/tn_x_query_snv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#eval_cle_gold.cwl/true_negative_bed"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 9
                    },
                    "id": "#eval_cle_gold.cwl/tumor_indel_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#eval_cle_gold.cwl/tumor_snv_bam_readcount_tsv"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "gold_eval.out"
                    },
                    "id": "#eval_cle_gold.cwl/eval_out"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "vaf_report.out"
                    },
                    "id": "#eval_cle_gold.cwl/vaf_report"
                }
            ],
            "id": "#eval_cle_gold.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/bash",
                "directory_gatherer.sh"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:xenial"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 1000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "directory_gatherer.sh",
                            "entry": "set -eou pipefail\n\noutdir=\"$1\"\nfiles=\"${@:2}\"\nmkdir $outdir\nchmod -R 777 $outdir\ncp -t $outdir $files\n\nexit 0\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#gather_to_sub_directory.cwl/files"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#gather_to_sub_directory.cwl/outdir"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.outdir)"
                    },
                    "id": "#gather_to_sub_directory.cwl/gathered_directory"
                }
            ],
            "id": "#gather_to_sub_directory.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "/usr/local/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "cp",
                "$(inputs.bam.basename).bai",
                "$(runtime.outdir)/$(inputs.bam.nameroot).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.11--h6270b1f_0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "${ var f = inputs.bam; delete f.secondaryFiles; return f }"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/local/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.11--h6270b1f_0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 4.1.8.1)",
            "baseCommand": [
                "/gatk/gatk",
                "--java-options",
                "-Xmx4g",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.8.1"
                }
            ],
            "arguments": [
                "-O",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--exclude-filtered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--sample-name",
                        "position": 5
                    },
                    "doc": "include genotypes from this sample",
                    "id": "#select_variants.cwl/samples_to_include"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#select_variants.cwl/select_type/INDEL",
                                "#select_variants.cwl/select_type/SNP",
                                "#select_variants.cwl/select_type/MIXED",
                                "#select_variants.cwl/select_type/MNP",
                                "#select_variants.cwl/select_type/SYMBOLIC",
                                "#select_variants.cwl/select_type/NO_VARIATION"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-select-type",
                        "position": 6
                    },
                    "doc": "select only a certain type of variants",
                    "id": "#select_variants.cwl/select_type"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "som.py compares variants in vcf by location and alleles (using bcftools isec).",
            "baseCommand": [
                "/opt/hap.py/bin/som.py"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 16000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "pkrusche/hap.py:v0.3.9"
                }
            ],
            "arguments": [
                "-N",
                "-o",
                "sompy"
            ],
            "stdout": "sompy.out",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#sompy.cwl/query_vcf"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-r",
                        "position": 1
                    },
                    "id": "#sompy.cwl/reference"
                },
                {
                    "type": "File",
                    "doc": "region of interest bed file to restrict",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 2
                    },
                    "id": "#sompy.cwl/roi_bed"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#sompy.cwl/truth_vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#sompy.cwl/sompy_out",
                    "outputBinding": {
                        "glob": "sompy.out"
                    }
                }
            ],
            "id": "#sompy.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
